package edu.berkeley.edu.cs160.groupjybz.realdealprototype;

import android.location.Address;
import android.location.Location;
import android.location.LocationManager;
import android.os.Bundle;
import android.util.Log;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.View;
import android.view.Menu.Item;
import android.view.View.OnClickListener;

import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.OverlayController;
import com.google.android.maps.Point;
import com.google.googlenav.DrivingDirection;
import com.google.googlenav.map.MapPoint;

public class MyDrivingDirectionsActivity extends MapActivity {
	private MapView mMapView;
	private MapController mController;
	private OverlayController mOverlayController;
	private Point mCurrentPoint;
	private LocationManager locationManager;
	private Location location;
	private static final int ZOOM_IN = 0;
	private static final int ZOOM_OUT = 1;
	private static final int TOGGLE_SAT = 2;
	private static final int TOGGLE_TRAFFIC = 3;
	private static final int BACK = 4;
	private MapPoint[] points=null;// = new Point[2];
	private Address address[]=null;
	
	private DrivingDirection myDD = null;
	private boolean foundDirections = false;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle icicle) {
		super.onCreate(icicle);
		Bundle extras = getIntent().getExtras();
		
		mMapView = new MapView(this);
        mController = mMapView.getController();
        mOverlayController = mMapView.createOverlayController();
        mCurrentPoint = new Point((int) (RealDealPrototypeActivity.getCurrentLocation()[0] * 1000000), (int)
                (RealDealPrototypeActivity.getCurrentLocation()[1] * 1000000));
        mController.animateTo(mCurrentPoint);
        double distance = extras.getDouble("distance");
        if (distance == 0.0)
        	mController.zoomTo(14);
        else
        	mController.zoomTo( 14 - ((int)(distance*10) / 14));
		
		/* Find the MapView we defined in the main.xml. */
		//MapView mMapView = (MapView)this.findViewById(R.id.myMapView);
		/* Retrieve its OverlayController. */
		OverlayController myOC = mMapView.createOverlayController();
		/* Add a new instance of our fancy Overlay-Class to the MapView. */
		myOC.add(new MyMapDrivingDirectionsOverlay(this), true);
		
		
		double lat = extras.getDouble("latitude");
		double log = extras.getDouble("longitude");
        if(lat != 0.0 && log != 0.0) {
        	points = new MapPoint[2];
        	MapPoint point = new MapPoint ((int) (lat * 1000000), 
        		(int) (log * 1000000));
        	points[1]=point;
        } else {
        	//points = new Point[1];
        	points = new MapPoint[2];
        	MapPoint point = new MapPoint((int) (37.826402 * 1000000), (int)
                    (-122.265078 * 1000000));
        	points[1]=point;
        }
        points[0] = new MapPoint(mCurrentPoint.getLatitudeE6(), mCurrentPoint.getLongitudeE6());
        
		MyDrivingDirectionsActivity.this.startFetchDirections(points[0],"", points[1], "");
		setContentView(mMapView);
	}

	/** Offers the DrivingDirections to the Overlay. */
	public DrivingDirection getDrivingDirections() {
		return this.myDD;
	}

	private void startFetchDirections(MapPoint from_pos, String from_name,
			MapPoint to_pos, String to_name) {
		/* mDD is a class variable for the activity that will
		 * hold an instance of the DrivingDirection object created here. */
		this.myDD = new DrivingDirection(from_pos, from_name, to_pos, to_name);
		if (this.myDD != null) {
			/* Add the request the dispatcher */
			this.getDispatcher().addDataRequest(this.myDD);

			Thread t = new Thread(new Runnable() {
				public void run() {
					/* Wait for the search to be complete... */
					while (!MyDrivingDirectionsActivity.this.myDD.isComplete()) { 
						try {
							Thread.sleep(100);
						} catch (InterruptedException e) {
							Log.e("DEBUGTAG", "'!MyDrivingDirectionsActivity.this.myDD.isComplete()' was interruoted.",e);
						}
					}
					/* Check to see if any Placemarks were found.. 
					 * if 0 then there is no route! */
					if (MyDrivingDirectionsActivity.this.myDD.getState() != DrivingDirection.SUCCESS_STATUS) {
						/* Set a flag to let the program know 
						 * the directions are done... */
						MyDrivingDirectionsActivity.this.foundDirections = true;
					} else{ /* no route.. */
						MyDrivingDirectionsActivity.this.foundDirections = true;
						MyDrivingDirectionsActivity.this.myDD = null;
						/* Let the user know that no route was found... */
					}
				}
			});
			t.start();
			/*while(myDD.getFormattedDistance()==null) {}
			
			mController.zoomTo();*/
		}
	}
	
	
	public void updateView() {
		Double lat = location.getLatitude()*1E6;
		Double lng = location.getLongitude()*1E6;
		Point point = new Point(lat.intValue(), lng.intValue());
		mController.centerMapTo(point, false);
	}
	
    public boolean onKeyDown(int keyCode, KeyEvent event) {
    	if (keyCode == KeyEvent.KEYCODE_DPAD_UP) {
    		int level = mMapView.getZoomLevel();
    		int lat = mCurrentPoint.getLatitudeE6();
    		int log = mCurrentPoint.getLongitudeE6();
    		mCurrentPoint = new Point((int) (lat+800000/level/level), (int)
                    (log));
    		mController.animateTo(mCurrentPoint);
    		return true;
    	} else if (keyCode == KeyEvent.KEYCODE_DPAD_DOWN) {
    		int level = mMapView.getZoomLevel();
    		int lat = mCurrentPoint.getLatitudeE6();
    		int log = mCurrentPoint.getLongitudeE6();
    		mCurrentPoint = new Point((int) (lat-800000/level/level), (int)
                    (log));
    		mController.animateTo(mCurrentPoint);
    		return true;
    	} else if (keyCode == KeyEvent.KEYCODE_DPAD_RIGHT) {
    		int level = mMapView.getZoomLevel();
    		int lat = mCurrentPoint.getLatitudeE6();
    		int log = mCurrentPoint.getLongitudeE6();
    		mCurrentPoint = new Point((int) (lat), (int)
                    (log+800000/level/level));
    		mController.animateTo(mCurrentPoint);
    		return true;
    	} else if (keyCode == KeyEvent.KEYCODE_DPAD_LEFT) {
    		int level = mMapView.getZoomLevel();
    		int lat = mCurrentPoint.getLatitudeE6();
    		int log = mCurrentPoint.getLongitudeE6();
    		mCurrentPoint = new Point((int) (lat), (int)
                    (log-800000/level/level));
    		mController.animateTo(mCurrentPoint);
    		return true;
    	} else if (keyCode == KeyEvent.KEYCODE_I) {
            // Zoom In
            int level = mMapView.getZoomLevel();
            mMapView.getController().zoomTo(level + 1);
            return true;
        } else if (keyCode == KeyEvent.KEYCODE_O) {
            // Zoom Out
            int level = mMapView.getZoomLevel();
            mMapView.getController().zoomTo(level - 1);
            return true;
        } else if (keyCode == KeyEvent.KEYCODE_S) {
            // Switch on the satellite images
            mMapView.toggleSatellite();
            return true;
        } else if (keyCode == KeyEvent.KEYCODE_T) {
            // Switch on traffic overlays
            mMapView.toggleTraffic();
            return true;
        } else if (keyCode == KeyEvent.KEYCODE_BACK) {
        	setResult(RESULT_OK, null, null);
            finish();
            return true;
        }
        return false;
    }
    
    public boolean onCreateOptionsMenu(Menu menu) {
		//each represent a feature
		menu.add(0, ZOOM_IN, R.string.zoom_in);
		menu.add(0, ZOOM_OUT, R.string.zoom_out);
		menu.add(0, TOGGLE_SAT, R.string.toggle_sat);
		menu.add(0, TOGGLE_TRAFFIC, R.string.toggle_traffic);
		menu.add(0, BACK, R.string.back);
		return super.onCreateOptionsMenu(menu);
	}
    
	public boolean onMenuItemSelected(int featureId, Item item) {
		switch(item.getId()) {
        case ZOOM_IN:  
            int levela = mMapView.getZoomLevel();
            mMapView.getController().zoomTo(levela + 1);
            return true;
        case ZOOM_OUT:  
            int levelb = mMapView.getZoomLevel();
            mMapView.getController().zoomTo(levelb - 1);
            return true;
        case TOGGLE_SAT:  
            mMapView.toggleSatellite();
            return true;
        case TOGGLE_TRAFFIC:  
            mMapView.toggleTraffic();
            return true;
        case BACK:
        	setResult(RESULT_OK, null, null);
            finish();
            return true;
        }
        return super.onMenuItemSelected(featureId, item);
	}
}