package edu.berkeley.edu.cs160.groupjybz.realdealprototype;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.CheckBox;
import android.widget.ArrayAdapter;
import android.widget.Toast;
import android.content.Context;
import android.database.Cursor;

public class PreferenceSetting extends Activity 
{
	private Context mContext = this;
	private Cursor mPreference;
	private RealDealDbAdapter mDbHelper;
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle icicle) 
    {
        super.onCreate(icicle);
        preferenceMenu();
    }
    
    private void preferenceMenu()
    {
    	mDbHelper = new RealDealDbAdapter(this);
        mDbHelper.open();
    	
    	setContentView(R.layout.preference);
    	
    	final EditText defaultRadius = (EditText) findViewById(R.id.default_radius);
    	final EditText voteRatio = (EditText) findViewById(R.id.vote_ratio);
    	final EditText promotionsPerStore = (EditText) findViewById(R.id.promotions_per_store);
    	
    	final Spinner distanceUnit = (Spinner) findViewById(R.id.distance_unit);
        ArrayAdapter<CharSequence> adapter = ArrayAdapter.createFromResource(
                this, R.array.distance_units, R.layout.spinner_dropdown_view);
        adapter.setDropDownViewResource(R.layout.spinner_dropdown_item);
        distanceUnit.setAdapter(adapter);
    	
        final CheckBox clothing = (CheckBox) findViewById(R.id.clothing);
    	final CheckBox convientStore = (CheckBox) findViewById(R.id.convient_store);
    	final CheckBox entertainment = (CheckBox) findViewById(R.id.entertainment);
    	final CheckBox electronics = (CheckBox) findViewById(R.id.electronics);
    	final CheckBox others = (CheckBox) findViewById(R.id.others);
    	final CheckBox restaurant = (CheckBox) findViewById(R.id.restaurant);
    	
    	mPreference = mDbHelper.fetchPreference();
        startManagingCursor(mPreference);
        if(mPreference.getInt(mPreference.getColumnIndex("Clothing")) != 0)
        {
        	clothing.setChecked(true);
        }
        if(mPreference.getInt(mPreference.getColumnIndex("Convenient")) != 0)
        {
        	convientStore.setChecked(true);
        }
        if(mPreference.getInt(mPreference.getColumnIndex("Entertainment")) != 0)
        {
        	entertainment.setChecked(true);
        }
        if(mPreference.getInt(mPreference.getColumnIndex("Electronics")) != 0)
        {
        	electronics.setChecked(true);
        }
        if(mPreference.getInt(mPreference.getColumnIndex("Restaurant")) != 0)
        {
        	restaurant.setChecked(true);
        }
        if(mPreference.getInt(mPreference.getColumnIndex("Others")) != 0)
        {
        	others.setChecked(true);
        }
    	    	
    	final Button save = (Button) findViewById(R.id.save);
		save.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				Toast.makeText(mContext, "Preference Saved", Toast.LENGTH_SHORT).show();
				Bundle bundle = new Bundle();
				String radius = defaultRadius.getText().toString();
				if (radius.length()>0) 
				{
					double rad = Double.valueOf(radius).doubleValue();
					if(rad >= 0)
					{
						bundle.putDouble(RealDealDbAdapter.KEY_RADIUS, rad);
					}
				}
				String ppstore = promotionsPerStore.getText().toString();
				if (ppstore.length()>0) 
				{
					int pps = Integer.valueOf(ppstore);
					if(pps >= 1)
					{
						bundle.putInt(RealDealDbAdapter.KEY_PROMOTION_PER_STORE, pps);
					}
				}
				String vote = voteRatio.getText().toString();
				if (vote.length()>0) 
				{
					double voteRatio = Double.valueOf(vote).doubleValue();
					if(voteRatio >= 0 && voteRatio <= 100)
					{
						bundle.putDouble(RealDealDbAdapter.KEY_VOTERATIO, voteRatio/(double)100);
					}
				}
				bundle.putBoolean("Clothing", clothing.isChecked());
				bundle.putBoolean("Convenient", convientStore.isChecked());
				bundle.putBoolean("Entertainment", entertainment.isChecked());
				bundle.putBoolean("Electronics", electronics.isChecked());
				bundle.putBoolean("Others", others.isChecked());
				bundle.putBoolean("Restaurant", restaurant.isChecked());
				
				bundle.putString("distanceUnit",distanceUnit.getSelectedItem().toString());
				setResult(RESULT_OK, null, bundle);
				//SystemClock.sleep(1000);
                finish();
			}
		});
		
		Button cancel = (Button) findViewById(R.id.cancel);
		cancel.setOnClickListener(new View.OnClickListener() {
			public void onClick(View v) {
				setResult(RESULT_CANCELED, null, null);
                finish();
			}
		});
		
		distanceUnit.setOnKeyListener(new View.OnKeyListener(){
        	public boolean onKey(View view, int keyCode, KeyEvent event) {
        		if (keyCode == KeyEvent.KEYCODE_DPAD_LEFT) {
        			defaultRadius.requestFocus();
        			return true;
        		} else if (keyCode == KeyEvent.KEYCODE_DPAD_RIGHT) {
        			return true;
        		}
        		return false;
        	}
        });
    }
    
	@Override
	protected void onFreeze(Bundle outState) {
		// TODO Auto-generated method stub
		super.onFreeze(outState);
	}

	@Override
	protected void onPause() {
		// TODO Auto-generated method stub
		super.onPause();
	}

	@Override
	protected void onResume() {
		// TODO Auto-generated method stub
		super.onResume();
	}
    
	protected void onActivityResult(int requestCode, int resultCode,
			String data, Bundle extras) {
		// TODO Auto-generated method stub
		super.onActivityResult(requestCode, resultCode, data, extras);
		switch(requestCode) {
             
		}
	}
    
    
}


