package edu.berkeley.edu.cs160.groupjybz.realdealprototype;

import com.google.android.maps.Point;

import android.app.ListActivity;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.View;
import android.view.Menu.Item;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.Spinner;

public class RealDealPrototypeActivity extends ListActivity 
{
	final public static int ACTIVITY_ADVANCED_SEARCH = 1;
	final public static int ACTIVITY_PREFERENCE = 2;
	final public static int ACTIVITY_ADD_PROMOTION = 3;
	final public static int ACTIVITY_PROMOTION_DESCRIPTION = 4;
	final public static int DEFAULT_LIST = 5;
	
	private RealDealDbAdapter mDbHelper;
	private Cursor mResultPromotion;
	private EditText mSearchText;
	private Cursor mPreference;
		
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle icicle) 
    {
    	super.onCreate(icicle);
        setContentView(R.layout.promotionlist);
        mDbHelper = new RealDealDbAdapter(this);
        mDbHelper.open();
                
        mSearchText = (EditText) findViewById(R.id.searchkeyword);
        
        final Button searchButton = (Button) findViewById(R.id.searchbutton);
        
        final Spinner types = (Spinner) findViewById(R.id.typespinner1);
        ArrayAdapter<CharSequence> tAdapter = ArrayAdapter.createFromResource(
                this, R.array.types, R.layout.spinner_dropdown_view);
        tAdapter.setDropDownViewResource(R.layout.spinner_dropdown_item);
        types.setAdapter(tAdapter);
        types.setOnKeyListener(new View.OnKeyListener(){
        	public boolean onKey(View view, int keyCode, KeyEvent event) {
        		if (keyCode == KeyEvent.KEYCODE_DPAD_LEFT) {
        			searchButton.requestFocus();
        			return true;
        		} else if (keyCode == KeyEvent.KEYCODE_DPAD_RIGHT)
        			return true;
        		return false;
        	}
        });
        
        fillData();
        
        searchButton.setOnClickListener(new View.OnClickListener() {

            public void onClick(View view) {
                String tempSearchWord = mSearchText.getText().toString();
                if (tempSearchWord.length()==0)
                {
                	tempSearchWord = null;
                }
                String tempType = types.getSelectedItem().toString();
                if (tempType.compareTo("All") == 0)
                {
                	tempType = null;
                }
                mResultPromotion = mDbHelper.fetchMatchingPromotions(tempType, tempSearchWord, null, null, -1, null, -1);
                fillResultData(mResultPromotion);
            }
           
        });
        
        mSearchText.setOnKeyListener(new View.OnKeyListener(){
        	public boolean onKey(View view, int keyCode, KeyEvent event) {
        		if (keyCode == KeyEvent.KEYCODE_DPAD_CENTER) {
                    String tempSearchWord = mSearchText.getText().toString();
                    if (tempSearchWord.length()==0)
                    {
                    	tempSearchWord = null;
                    }
                    String tempType = types.getSelectedItem().toString();
                    if (tempType.compareTo("All") == 0)
                    {
                    	tempType = null;
                    }
                    mResultPromotion = mDbHelper.fetchMatchingPromotions(tempType, tempSearchWord, null, null, -1, null, -1);
                    fillResultData(mResultPromotion);
        			
        			return true;
        		}
        		return false;
        	}
        });
    }
    
    
    
    private void fillData() 
    {
    	mPreference = mDbHelper.fetchPreference();
        startManagingCursor(mPreference);
        //get preferred promotion list
    	double radius = mPreference.getDouble(mPreference.getColumnIndex(RealDealDbAdapter.KEY_RADIUS));
    	int pps = mPreference.getInt(mPreference.getColumnIndex(RealDealDbAdapter.KEY_PROMOTION_PER_STORE));
    	double voteRatio = mPreference.getDouble(mPreference.getColumnIndex(RealDealDbAdapter.KEY_VOTERATIO));
    	Bundle types = new Bundle();
		types.putBoolean("Clothing", (mPreference.getInt(mPreference.getColumnIndex("Clothing")) != 0));
		types.putBoolean("Convenient", (mPreference.getInt(mPreference.getColumnIndex("Convenient")) != 0));
		types.putBoolean("Entertainment", (mPreference.getInt(mPreference.getColumnIndex("Entertainment")) != 0));
		types.putBoolean("Electronics", (mPreference.getInt(mPreference.getColumnIndex("Electronics")) != 0));
		types.putBoolean("Others", (mPreference.getInt(mPreference.getColumnIndex("Others")) != 0));
		types.putBoolean("Restaurant", (mPreference.getInt(mPreference.getColumnIndex("Restaurant")) != 0));
        Cursor promotionCursor = mDbHelper.fetchPreferredPromotions(radius, pps, voteRatio, types);
        startManagingCursor(promotionCursor);
        
        // Create an array to specify the fields we want to display in the list
        String[] from = new String[]{RealDealDbAdapter.KEY_TYPE, RealDealDbAdapter.KEY_DIS, RealDealDbAdapter.KEY_KEYWORD};
        
        // and an array of the fields we want to bind those fields to
        int[] to = new int[]{R.id.type1, R.id.dis1, R.id.keyword1};
        
        // Now create a simple cursor adapter and set it to display
        SimpleCursorAdapter promotions = 
        	    new SimpleCursorAdapter(this, R.layout.promotionlist_row1, promotionCursor, from, to);
        setListAdapter(promotions);
    }
    
    private void fillResultData(Cursor promotionCursor)
    {
    	startManagingCursor(promotionCursor);
        
        // Create an array to specify the fields we want to display in the list (only TITLE)
        String[] from = new String[]{RealDealDbAdapter.KEY_TYPE, RealDealDbAdapter.KEY_DIS, RealDealDbAdapter.KEY_KEYWORD};
        
        // and an array of the fields we want to bind those fields to (in this case just text1)
        int[] to = new int[]{R.id.type1, R.id.dis1, R.id.keyword1};
        
        // Now create a simple cursor adapter and set it to display
        SimpleCursorAdapter promotions = 
        	    new SimpleCursorAdapter(this, R.layout.promotionlist_row1, promotionCursor, from, to);
        setListAdapter(promotions);
    }
    
    //get the current GPS location
    public static double[] getCurrentLocation()
    {
    	double[] currentLoc = new double[2];
    	currentLoc[0] = 37.826402;
    	currentLoc[1] = -122.265078;
    	return currentLoc;
    }
    
    //get the current address
    public static String getCurrentAddress()
    {
    	String currentAddr;
    	currentAddr = "12 W MacArthur Blvd, Alameda, CA";
    	return currentAddr;
    }
    
    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) 
    {
        super.onListItemClick(l, v, position, id);
        Intent i = new Intent(this, PromotionDescription.class);
        i.putExtra(RealDealDbAdapter.KEY_ROWID, id);
        startSubActivity(i, ACTIVITY_PROMOTION_DESCRIPTION);
    }
    
    public boolean onCreateOptionsMenu(Menu menu) {
		//each represent a feature
		menu.add(0, ACTIVITY_ADVANCED_SEARCH, R.string.advanced_search);
		menu.add(0, ACTIVITY_PREFERENCE, R.string.preference_setting);
		menu.add(0, ACTIVITY_ADD_PROMOTION, R.string.add_promotion);
		menu.add(0, DEFAULT_LIST, R.string.default_list);
		return super.onCreateOptionsMenu(menu);
	}
	
	public boolean onMenuItemSelected(int featureId, Item item) {
        switch(item.getId()) {
        case ACTIVITY_PREFERENCE:  
        	preferenceMenu();
            return true;
        case ACTIVITY_ADVANCED_SEARCH:  
        	advancedSearch();
            return true;
        case ACTIVITY_ADD_PROMOTION:  
        	addPromotion();
            return true;
        case DEFAULT_LIST:  
        	fillData();
            return true;
        }
        return super.onMenuItemSelected(featureId, item);
	}
	
	protected void onActivityResult(int requestCode, int resultCode,
			String data, Bundle extras) {
		// TODO Auto-generated method stub
		super.onActivityResult(requestCode, resultCode, data, extras);
		switch(requestCode) {
        case ACTIVITY_PREFERENCE:
        	if(resultCode == RESULT_OK)
        	{
        		double radius = extras.getDouble(RealDealDbAdapter.KEY_RADIUS, -1);
        		int pps = extras.getInt(RealDealDbAdapter.KEY_PROMOTION_PER_STORE, -1);
        		double voteRatio = extras.getDouble(RealDealDbAdapter.KEY_VOTERATIO, -1);
        		Bundle types = new Bundle();
        		types.putBoolean("Clothing", extras.getBoolean("Clothing"));
        		types.putBoolean("Convenient", extras.getBoolean("Convenient"));
        		types.putBoolean("Entertainment", extras.getBoolean("Entertainment"));
        		types.putBoolean("Electronics", extras.getBoolean("Electronics"));
        		types.putBoolean("Others", extras.getBoolean("Others"));
        		types.putBoolean("Restaurant", extras.getBoolean("Restaurant"));
        		
        		mDbHelper.setPreference(radius, pps, voteRatio, types);
        		fillData();
        	}
        	break;
        case ACTIVITY_ADVANCED_SEARCH:
        	if(resultCode == RESULT_OK) {
            	String keyWord = extras.getString(RealDealDbAdapter.KEY_KEYWORD);
            	if(keyWord.length()==0)
            		keyWord = null;
            	String location = extras.getString(RealDealDbAdapter.KEY_LOCATION);
            	if(location.length()==0)
            		location = null;
            	String storeName = extras.getString(RealDealDbAdapter.KEY_STORENAME);
            	if(storeName.length()==0)
            		storeName = null;
            	String type  = extras.getString(RealDealDbAdapter.KEY_TYPE);
            	if(type.length()==0 || type.compareTo("All")==0)
            		type = null;
            	double dis = extras.getDouble(RealDealDbAdapter.KEY_DIS, -1);
            	double voteRatio = extras.getDouble(RealDealDbAdapter.KEY_VOTERATIO, -1);
            	mResultPromotion = mDbHelper.fetchMatchingPromotions(type, keyWord, null, location, dis, storeName, voteRatio);
        		fillResultData(mResultPromotion);
        	}
        	break;
        case ACTIVITY_ADD_PROMOTION:
        	if(resultCode == RESULT_OK){
            	String keyWord = extras.getString(RealDealDbAdapter.KEY_KEYWORD);
            	String description = extras.getString(RealDealDbAdapter.KEY_DESCRIPTION);
            	String location = extras.getString(RealDealDbAdapter.KEY_LOCATION);
            	String storeName = extras.getString(RealDealDbAdapter.KEY_STORENAME);
            	String type  = extras.getString(RealDealDbAdapter.KEY_TYPE);
            	mDbHelper.createPromotion(type, keyWord, description, location, storeName);
        	}
        	fillData();
        	break;
		}
	}
	
    public void preferenceMenu() {
    	Intent i = new Intent(this, PreferenceSetting.class);
        startSubActivity(i, ACTIVITY_PREFERENCE);
    }
    public void advancedSearch() {
    	Intent i = new Intent(this, AdvancedSearch.class);
        startSubActivity(i, ACTIVITY_ADVANCED_SEARCH);
    }
    public void addPromotion() {
    	Intent i = new Intent(this, AddPromotion.class);
        startSubActivity(i, ACTIVITY_ADD_PROMOTION);
    }
    
	@Override
	protected void onFreeze(Bundle outState) {
		// TODO Auto-generated method stub
		super.onFreeze(outState);
	}

	@Override
	protected void onPause() {
		// TODO Auto-generated method stub
		super.onPause();
	}

	@Override
	protected void onResume() {
		// TODO Auto-generated method stub
		super.onResume();
	}
}